.. _overview:

Documentation overview
======================

Welcome to DebOps! This page provides an overview of the documentation included
in the project. In the online version, you can use the sidebar to switch
between documentation sections.


Introduction
  The "Introduction" section contains information about getting DebOps up and running.

  This includes a guide on :ref:`getting started <getting-started>`,
  :ref:`installation instructions <install>`,
  and :ref:`answers to commonly asked questions <faq>`.

User Manual
  This section contains documentation about the usage of DebOps.
  It is intended to be an exhaustive reference of all DebOps user-facing features.

  It includes a guide to :ref:`project directories <project_directory>`,
  the ways DebOps :ref:`builds on top of Ansible <debops_for_ansible>`,
  the usage of the various :command:`debops` :ref:`scripts <cli>`,
  as well as the documentation of DebOps' extensive collection of
  :ref:`playbooks <playbooks>` and :ref:`roles <role_index>`.


Admin Recipes
  Here you can find guides for an IT infrastructure managed by DebOps.

  This section explains common properties of the hosts that are managed,
  and provides ways to configure various infrastructure elements.


Developer guide
  This section focuses on DebOps project development.

  It contains information about best practices involving Ansible coding style,
  how various applications should be installed,
  how DebOps code is validated and tested,
  and how to contribute to the project yourself.


The DebOps Project
  This section covers anything related to the DebOps project itself.

  Documentation of various application programming interfaces available in the
  DebOps project can be found here.

  You can also read about what the
  :ref:`goals and philosophy of the project <philosophy>` are,
  and how to :ref:`reach the community <community>`.


News
  In this section you can read about :ref:`recent changes <changelog>` in the
  project and stable releases. You can also find here :ref:`information about
  manual upgrade steps <upgrade_notes>` needed to be done when switching to the
  next DebOps release.
